==> kubernetes-model-flowcontrol-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationSpecFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationSpecFluent<A extends PriorityLevelConfigurationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitedPriorityLevelConfiguration getLimited();
  public LimitedPriorityLevelConfiguration buildLimited();
  public A withLimited(LimitedPriorityLevelConfiguration limited);
  public Boolean hasLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimitedLike(LimitedPriorityLevelConfiguration item);
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimitedLike(LimitedPriorityLevelConfiguration item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitedNested<N> extends Nested<N>,LimitedPriorityLevelConfigurationFluent<PriorityLevelConfigurationSpecFluent.LimitedNested<N>>{
    public N and();
    public N endLimited();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationSpecFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationSpecFluent<A extends PriorityLevelConfigurationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLimited instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitedPriorityLevelConfiguration getLimited();
  public LimitedPriorityLevelConfiguration buildLimited();
  public A withLimited(LimitedPriorityLevelConfiguration limited);
  public Boolean hasLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> withNewLimitedLike(LimitedPriorityLevelConfiguration item);
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimited();
  public PriorityLevelConfigurationSpecFluent.LimitedNested<A> editOrNewLimitedLike(LimitedPriorityLevelConfiguration item);
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LimitedNested<N> extends Nested<N>,LimitedPriorityLevelConfigurationFluent<PriorityLevelConfigurationSpecFluent.LimitedNested<N>>{
    public N and();
    public N endLimited();
    
  }
  
}
